# Başlayalım

OpenSesame'ye hoşgeldiniz. Size nasıl yardımcı olabilirim?

<table><tr><td>

Yeni deneye başla:<br />
%(templates)s

</td><td>

%(recent_experiments)s

</td></tr></table>

OpenSesame'ye bağışta bulunmak ister misiniz? Çok hızlı ve kolay bir şekilde bağışta bulunabilirsiniz.

[Paypal ile bağış](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=QEWKSAY4WMKRW){: .important-button}

Daha fazla öğrenmek için:

[Dökümanları oku](http://osdoc.cogsci.nl){: .button}<br />
[Forumda bir soru sor](http://forum.cogsci.nl){: .button}<br />
